@@ -33,7 +33,8 @@ using System.Net; //getIP stuff
 //[WebService(Namespace="http://localhost:8080/", //work to connect to corall development from client (from browser works only when online)
 //[WebService(Namespace="http://80.32.81.197:8080/", //works to connect with pinux xen from client (from browser don't works) WORKS FROM CLIENT
 //[WebService(Namespace="http://server.chronojump.org:8080/", //works to connect with pinux xen from client (from browser don't works) WORKS FROM CLIENT (important: needed the last '/')
-[WebService(Namespace="http://server.chronojump.org/", //works to connect with pinux xen from client (from browser don't works) WORKS FROM CLIENT (important: needed the last '/')
+//[WebService(Namespace="http://server.chronojump.org/", //works to connect with pinux xen from client (from browser don't works) WORKS FROM CLIENT (important: needed the last '/')
+[WebService(Namespace="http://server.chronojump.org:8080/", //2013 server
 	Description="ChronojumpServer")]
 [Serializable]
 public class ChronojumpServer {
